#=============================================================
#  http://www.sallyx.org/sally/c/autoools/m4
#=============================================================
#
# SYNOPSIS
#
#   SALLYX_HEADER_DBM([action-if-found],[action-if-not-found])
#
# DESCRIPTION
#
# This macro checks for [N|G]DBM header files.
# It must be run after:
# AC_CHECK_LIB([gdbm], [main])
# AC_CHECK_LIB([gdbm_compat], [main])
#
# The following preprocessor symbols may be defined by this macro if the
# appropriate conditions are met:
#     HAVE_GDBM              - if any dbm header was found
#     HAVE_GDBMNDBM_H        - if gdbm-ndbm.h was found
#     HAVE_GDBM_NDBM_H       - if gdbm/ndbm.h was found
#     HAVE_NDBM_H            - if ndbm.h was found
#
# To use the HAVE_xxx_H preprocessor symbols, insert the following into
# your system.h (or equivalent) header file:
#
#     #if defined HAVE_GDBMNDBM_H
#     #  include <gdbm-ndbm.h>
#     #elif defined HAVE_GDBM_NDBM_H
#     #  include <gdbm/ndbm.h>
#     #elif defined HAVE_NDBM_H
#     #  include <ndbm.h>
#     #else
#     #  error "[g|n]dbm header file required"
#     #endif
#
#
# LICENCE
#
# do What The Fuck you want to Public License
#
# Version 1.0, March 2000
# Copyright (C) 2000 Banlu Kemiyatorn (d).
# 136 Nives 7 Jangwattana 14 Laksi Bangkok
# Everyone is permitted to copy and distribute verbatim copies
# of this license document, but changing it is not allowed.
# 
# Ok, the purpose of this license is simple
# and you just
#
# DO WHAT THE FUCK YOU WANT TO.

# serial 3

AC_DEFUN([SALLYX_HEADER_DBM],[
            AC_CACHE_CHECK([for working gdbm-ndbm.h], [sallyx_cv_header_gdbmndbm_h], [
                AC_LINK_IFELSE([AC_LANG_PROGRAM([[
                        @%:@include <gdbm-ndbm.h>
                    ]], [[
			    dbm_open("/tmp/test.db", 0, 0);
                    ]])],
                    [sallyx_cv_header_gdbmndbm_h=yes],
                    [sallyx_cv_header_gdbmndbm_h=no])
            ])
            AS_IF([test "x$sallyx_cv_header_gdbmndbm_h" = xyes], [
		sallyx_header_dbm=1
		AC_DEFINE([HAVE_GDBM], [1], [Define to 1 if any [n|g]dbm header found])
		AC_DEFINE([HAVE_GDBMNDBM_H], [1], [Define to 1 if gdbm-ndbm.h found])
            ])

            AC_CACHE_CHECK([for working gdbm/ndbm.h], [sallyx_cv_header_gdbm_ndbm_h], [
                AC_LINK_IFELSE([AC_LANG_PROGRAM([[
                        @%:@include <gdbm/ndbm.h>
                    ]], [[
			    dbm_open("/tmp/test.db", 0, 0);
                    ]])],
                    [sallyx_cv_header_gdbm_ndbm_h=yes],
                    [sallyx_cv_header_gdbm_ndbm_h=no])
            ])
            AS_IF([test "x$sallyx_cv_header_gdbm_ndbm_h" = xyes], [
		sallyx_header_dbm=1
		AC_DEFINE([HAVE_GDBM], [1], [Define to 1 if any [n|g]dbm header found])
		AC_DEFINE([HAVE_GDBM_NDBM_H], [1], [Define to 1 if gdbm/ndbm.h found])
            ])

            AC_CACHE_CHECK([for working ndbm.h], [sallyx_cv_header_ndbm_h], [
                AC_LINK_IFELSE([AC_LANG_PROGRAM([[
                        @%:@include <ndbm.h>
                    ]], [[
			    dbm_open("/tmp/test.db", 0, 0);
                    ]])],
                    [sallyx_cv_header_ndbm_h=yes],
                    [sallyx_cv_header_ndbm_h=no])
            ])
            AS_IF([test "x$sallyx_cv_header_ndbm_h" = xyes], [
		sallyx_header_dbm=1
		AC_DEFINE([HAVE_GDBM], [1], [Define to 1 if any [n|g]dbm header found])
		AC_DEFINE([HAVE_NDBM_H], [1], [Define to 1 if ndbm.h found])
            ])

	    AS_IF([test "x$sallyx_header_dbm" == "x"], [$2], [$1])
])
