/*------------------------------------------------*/
/* 51ncurses/thread-ncurses.c                     */
#include "thread-ncurses.h"
#include <pthread.h>
#include <semaphore.h>

#define MAX_JOBS 10
#define MAX_WINDOWS 10

static THNcursesJob jobs[MAX_JOBS];
static int jobs_index = 0;
static WINDOW *windows[MAX_WINDOWS];
static int windows_index = 0;
static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
static sem_t sem;

void * thncurses_signal_thread(THNcursesJob * tjob) {
    sem_init(&sem, 0, 0);

    while(true) {
        while(sem_wait(&sem) != 0);
        thncurses_add_job(*tjob);
        thncurses_paint();
    }
}

void thncurses_signal(void) {
    sem_post(&sem);
}

bool thncurses_add_job(THNcursesJob job)
{
    while(pthread_mutex_lock(&mutex));
    if (jobs_index == MAX_JOBS) {
        pthread_mutex_unlock(&mutex);
        return false;
    }
    jobs[jobs_index++] = job;
    pthread_mutex_unlock(&mutex);
    return true;
}

bool thncurses_add_window(WINDOW * win)
{
    while(pthread_mutex_lock(&mutex));
    if (windows_index == MAX_WINDOWS) {
        pthread_mutex_unlock(&mutex);
        return false;
    }
    windows[windows_index++] = win;
    pthread_mutex_unlock(&mutex);
    return true;
}

void thncurses_paint(void)
{
    while(pthread_mutex_lock(&mutex));
    int j;
    for (j = 0; j < jobs_index; j++) {
        jobs[j].fce(jobs[j].data);
    }
    jobs_index = 0;
    j = 0;
    while (windows[j]) {
        wnoutrefresh(windows[j++]);
    }
    doupdate();
    pthread_mutex_unlock(&mutex);
}

void thncurses_stop(void)
{
    while(pthread_mutex_lock(&mutex));
    return;
}
/*------------------------------------------------*/
